pub enum Signing {
Required,
Optional,
NotSupported,
}Expand description
Indicates if a builder requires signing for bundles using X-Flashbots-Signature.
All builder besides Flashbots have signing as optional or not supported. If provided, the builder may give better priority to signed bundles.
Variants
Required
Bundle gets rejected if not signed.
Optional
Signing is optional and may give better priority.
NotSupported
Builder does not support signing.
Implementations
Sourceimpl Signing
impl Signing
Sourcepub const fn is_required(&self) -> bool
pub const fn is_required(&self) -> bool
Returns true if the builder requires signing for bundles.
Sourcepub fn is_optional(&self) -> bool
pub fn is_optional(&self) -> bool
Returns true if the builder supports signing, but it is optional.
Sourcepub fn is_not_supported(&self) -> bool
pub fn is_not_supported(&self) -> bool
Returns true if the builder does not support signing.